﻿Imports MapControlSamples.Common
Imports System
Imports Windows.ApplicationModel.Resources
Imports Windows.UI.Xaml
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Input
Imports Windows.UI.Xaml.Navigation

Namespace MapControlSamples
	Public NotInheritable Partial Class MenuPage
		Inherits Page
'INSTANT VB NOTE: The variable navigationHelper was renamed since Visual Basic does not allow class members with the same name:
		Private ReadOnly navigationHelper_Renamed As NavigationHelper
'INSTANT VB NOTE: The variable defaultViewModel was renamed since Visual Basic does not allow class members with the same name:
		Private ReadOnly defaultViewModel_Renamed As New ObservableDictionary()
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.NavigationCacheMode = NavigationCacheMode.Required

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState
		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		''' <summary>
		''' Gets the view model for this <see cref="Page"/>.
		''' This can be changed to a strongly typed view model.
		''' </summary>
		Public ReadOnly Property DefaultViewModel() As ObservableDictionary
			Get
				Return Me.defaultViewModel_Renamed
			End Get
		End Property

		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session. The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache. Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		''' <summary>
		''' Adds an item to the list when the app bar button is clicked.
		''' </summary>
		Private Sub AddAppBarButton_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
		End Sub


		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedTo(e)
		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region

		Private Sub btnBasicMap_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(BasicMapPage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnDefaultImage_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(DefaultImagePage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnCustomImage_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(CustomImagePage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnAddressToGeocode_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(AddressToGeopointPage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnGeocodeToAddress_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(GeopointToAddressPage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnControls_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(ControlsPage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnDrivingRoutes_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(DrivingRoutesPage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub

		Private Sub btnWalkingRoutes_Tapped(ByVal sender As Object, ByVal e As TappedRoutedEventArgs)
			If Not Frame.Navigate(GetType(WalkingRoutesPage)) Then
				Throw New Exception(Me.resourceLoader.GetString("NavigationFailedExceptionMessage"))
			End If
		End Sub
	End Class
End Namespace
